QueryStateData

Enum QueryStateData 

pub enum QueryStateData<Q: QueryCapability> {
    Pending,
    Loading {
        res: Option<Result<Q::Ok, Q::Err>>,
    },
    Settled {
        res: Result<Q::Ok, Q::Err>,
        settlement_instant: Instant,
    },
}

Variants



Pending

Has not loaded yet.



Loading

Is loading and may not have a previous settled value.

Fields

res: Option<Result<Q::Ok, Q::Err>>


Settled

Is not loading and has a settled value.

Fields

res: Result<Q::Ok, Q::Err>
settlement_instant: Instant

Implementations

Source

impl<Q: QueryCapability> QueryStateData<Q>

pub fn is_ok(&self) -> bool

Check if the state is QueryStateData::Settled and Result::Ok.

pub fn is_err(&self) -> bool

Check if the state is QueryStateData::Settled and Result::Err.

pub fn is_loading(&self) -> bool

Check if the state is QueryStateData::Loading.

pub fn is_pending(&self) -> bool

Check if the state is QueryStateData::Pending.

pub fn is_stale(&self, query: &Query<Q>) -> bool

Check if the state is stale or not, where stale means outdated.

pub fn ok(&self) -> Option<&Q::Ok>

Get the value as an Option.

pub fn unwrap(&self) -> &Result<Q::Ok, Q::Err>

Get the value as an Result if possible, otherwise it will panic.