Query

Struct Query 

pub struct Query<Q: QueryCapability> { /* private fields */ }

Implementations

Source

impl<Q: QueryCapability> Query<Q>

pub fn new(keys: Q::Keys, query: Q) -> Self

pub fn enable(self, enabled: bool) -> Self

Enable or disable this query so that it doesnt automatically run.

Defaults to true.

pub fn stale_time(self, stale_time: Duration) -> Self

For how long is the data considered stale. If a query subscriber is mounted and the data is stale, it will re run the query otherwise it return the cached data.

Defaults to Duration::ZERO, meaning it is marked stale immediately after it has been used.

pub fn clean_time(self, clean_time: Duration) -> Self

For how long the data is kept cached after there are no more query subscribers.

Defaults to 5min, meaning it clears automatically after 5 minutes of no subscribers to it.

pub fn interval_time(self, interval_time: Duration) -> Self

Every how often the query reruns.

Defaults to Duration::MAX, meaning it never re runs automatically.

Note: If multiple subscribers of the same query use different intervals, only the shortest one will be used.