pub struct GetQuery<Q: QueryCapability> { /* private fields */ }Implementations
Sourceimpl<Q: QueryCapability> GetQuery<Q>
impl<Q: QueryCapability> GetQuery<Q>
pub fn new(keys: Q::Keys, query: Q) -> Self
Sourcepub fn stale_time(self, stale_time: Duration) -> Self
pub fn stale_time(self, stale_time: Duration) -> Self
For how long is the data considered stale. If a query subscriber is mounted and the data is stale, it will re run the query.
Defaults to Duration::ZERO, meaning it is marked stale immediately.
Sourcepub fn clean_time(self, clean_time: Duration) -> Self
pub fn clean_time(self, clean_time: Duration) -> Self
For how long the data is kept cached after there are no more query subscribers.
Defaults to Duration::ZERO, meaning it clears automatically.